@@ -2,7 +2,7 @@
 
 #==============================================================================#
 # exerb.rb
-# $Id: exerb.rb,v 1.25 2003/01/23 05:44:28 yuya Exp $
+# $Id: exerb.rb,v 1.28 2003/02/21 04:46:05 yuya Exp $
 #==============================================================================#
 
 require 'getoptlong'
@@ -124,17 +124,17 @@ module ExerbCommand
     puts "Exerb #{Exerb::VERSION}"
     puts ""
 
-    puts "Usage: exerb [options] rbc-file"
+    puts "Usage: exerb.rb [options] recipe-file"
     puts ""
 
     puts "Options:"
     puts "  -c  --corename  specifies exerb-core name."
     puts "  -C  --corefile  specifies exerb-core file."
     puts "  -o  --output    specifies output file."
-    puts "  -z  --compress  compress the archive. (using Ruby/zlib)"
-    puts "  -v  --verbose   "
+    puts "  -z  --compress  enable archive compression. (using Ruby/zlib)"
+    puts "  -v  --verbose   enable verbose mode."
     puts "  -g  --debug     enable debug mode."
-    puts "  -V  --version   display version."
+    puts "  -V  --version   display version number."
     puts "  -h  --help      display this information."
     puts ""
 
