@@ -14,7 +14,7 @@
 =end
 
 
-SWIN_REQUIRED = "010701" unless defined?(SWIN_REQUIRED)
+SWIN_REQUIRED = "021215" unless defined?(SWIN_REQUIRED)
 VR_COMPATIBILITY_LEVEL=3 unless defined?(VR_COMPATIBILITY_LEVEL)
 
 require 'swin'
@@ -354,6 +354,15 @@ If you need to receive windows messages , this module is necessary.
     end
   end
 
+  def selfmsg_dispatching(methodname,*args)
+    smethod="self_#{methodname}".intern
+    if respond_to?(smethod) then
+      send(smethod,*args) 
+    else
+      nil
+    end
+  end
+
 end
 
 module VRMessageParentRelayer
@@ -374,6 +383,10 @@ module VRMessageParentRelayer
     @parent.controlmsg_dispatching(self,mthdname,*args)
   end
 
+  def selfmsg_dispatching(methodname,*args)
+    @parent.controlmsg_dispatching(self,methodname,*args)
+  end
+
   def msghandler(msg)   # almost same as VRMessageHandler#msghandler
     if @_vr_msg_norelays.include?(msg.msg) then   # no relays
       return super
@@ -505,7 +518,8 @@ This module provides the features to be the parent of the child windows.
     c
   end
 
-  def addControl(type,name,caption, x,y,w,h, style=0)
+  VR_ADDCONTROL_FEWARGS=false
+  def addControl(type,name,caption, x=10,y=10,w=10,h=10, style=0)
     c = createControl(type,name,caption, x,y,w,h,style)
     cid=newControlID
     registerControl(c,name,cid) 
@@ -517,7 +531,7 @@ This module provides the features to be the parent of the child windows.
 
   def addArrayedControl(num,type,name,caption,x=0,y=0,w=10,h=10,style=0)
 #p method(:addControl).arity
-    if method(:addControl).arity==-4 then
+    if self.type::VR_ADDCONTROL_FEWARGS then
       c = addControl(type,"",caption,style)
     else
       c = addControl(type,"",caption,x,y,w,h,style)
@@ -795,13 +809,20 @@ Use VRResizeSensitive instead of this.
 =end
 
 module VRUserMessageUseable
+  module ReservedMsg
+    WM_VR_OLEDND      = 1
+    WM_VR_TRAYNOTIFY  = 2
+  end
+
 =begin
 == VRUserMessageUseable
 This module is for using user-defined Windows-system messages.
 
-=== registerUserMessage(messageid,eventname)
+--- registerUserMessage(messageid,eventname,offset=0x100)
     Registers an user-defined message whose eventname is ((|eventname|)).
-    On the Windows system, this message is assigned (WM_USER + messageid).
+    On your Windows system, this message is assigned for 
+    (WM_APP + messageid + offset).
+    Argument ((|offset|)) is only for vruby system use. Don't use it.
 
 === EventHandler
 --- self_((*userdefinedname*))(wparam,lparam)
@@ -818,8 +839,8 @@ This module is for using user-defined Windows-system messages.
     usermessageuseableinit
   end
 
-  def registerUserMessage(messageid,eventname)
-    msg = WMsg::WM_APP+messageid
+  def registerUserMessage(messageid,eventname,offset=0x100)
+    msg = WMsg::WM_APP+messageid+offset
     addEvent msg
     addHandler(msg, eventname,MSGTYPE::ARGINTINT,nil) 
     @_vr_usermessages[eventname]=msg
@@ -968,6 +989,11 @@ class, is available.
   def height
     @desktop.h
   end
+  alias w :width
+  alias h :height
+  def x() @desktop.x; end
+  def y() @desktop.y; end
+
 end
 
 VRLocalScreen=
