@@ -1,16 +1,16 @@
 
 #==============================================================================#
 # exerb/version.rb
-# $Id: version.rb,v 1.8 2003/02/10 04:14:32 yuya Exp $
+# $Id: version.rb,v 1.10 2003/02/21 05:14:48 yuya Exp $
 #==============================================================================#
 
 #==============================================================================#
 # Exerb Module
 module Exerb
 
-  VERSION = '2.6.1'
+  VERSION = '2.6.2'
 
-end
+end # Exerb
 
 #==============================================================================#
 #==============================================================================#
