@@ -1,4 +1,4 @@
-// $Id: BRbReadNode.cpp,v 1.59 2003/02/11 16:44:09 yuya Exp $
+// $Id: BRbReadNode.cpp,v 1.63 2003/02/21 02:19:10 yuya Exp $
 
 #ifdef BRB_READER
 
@@ -50,17 +50,19 @@ BRbReadNode::read()
 
 	m_strtbl.load(m_buffer);
 
-	m_debug.printf("reading node.\n");
+#ifdef DEBUG
+	m_debug.printf("============================================================\n");
+#endif
 
 	top_local_init();
 	NODE* node = read_node_opt();
 	top_local_setup();
 
-	m_debug.printf("read node.\n");
-
+#ifdef DEBUG
 	m_debug.printf("============================================================\n");
 	m_debug.dumpnode(node);
 	m_debug.printf("============================================================\n");
+#endif
 
 	return node;
 }
@@ -79,34 +81,32 @@ NODE*
 BRbReadNode::read_node()
 {
 	byte type = read_byte();
-	BRbLevelCounter counter(type);
 
+#ifdef DEBUG
+	BRbLevelCounter counter(type);
 	m_debug.printf("R:%02i:%s\n", counter.level(), BRbNode::get_node_name(type));
+#endif
 
 	switch ( type ) {
 		case NODE_ALIAS:
-		{
-			ID new_id = read_id();
-			ID old_id = read_id();
-			return NEW_ALIAS(new_id, old_id);
-		}
 		case NODE_VALIAS:
 		{
 			ID new_id = read_id();
 			ID old_id = read_id();
-			return NEW_VALIAS(new_id, old_id);
+			switch ( type ) {
+			case NODE_ALIAS:  return NEW_ALIAS(new_id, old_id);
+			case NODE_VALIAS: return NEW_VALIAS(new_id, old_id);
+			}
 		}
 		case NODE_AND:
-		{
-			NODE* n1st = read_node();
-			NODE* n2nd = read_node();
-			return logop(NODE_AND, n1st, n2nd);
-		}
 		case NODE_OR:
 		{
 			NODE* n1st = read_node();
 			NODE* n2nd = read_node();
-			return logop(NODE_OR, n1st, n2nd);
+			switch ( type ) {
+			case NODE_AND: return logop(NODE_AND, n1st, n2nd);
+			case NODE_OR:  return logop(NODE_OR, n1st, n2nd);
+			}
 		}
 		case NODE_ARGS:
 		{
@@ -317,7 +317,6 @@ BRbReadNode::read_node()
 		}
 		case NODE_DEFS:
 		{
-			//NODE* node = NEW_DEFS(...);
 			NODE* node = rb_node_newnode(NODE_DEFS, 0, 0, 0);
 			node->nd_mid  = read_id();
 			node->nd_recv = read_node();
@@ -366,28 +365,18 @@ BRbReadNode::read_node()
 			return NEW_FALSE();
 		}
 		case NODE_DOT2:
-		{
-			NODE* from = read_node();
-			NODE* to   = read_node();
-			return NEW_DOT2(from, to);
-		}
 		case NODE_DOT3:
-		{
-			NODE* from = read_node();
-			NODE* to   = read_node();
-			return NEW_DOT3(from, to);
-		}
 		case NODE_FLIP2:
-		{
-			NODE* from = read_node();
-			NODE* to   = read_node();
-			return rb_node_newnode(NODE_FLIP2, from, to, 0);
-		}
 		case NODE_FLIP3:
 		{
 			NODE* from = read_node();
 			NODE* to   = read_node();
-			return rb_node_newnode(NODE_FLIP3, from, to, 0);
+			switch ( type ) {
+			case NODE_DOT2:  return NEW_DOT2(from, to);
+			case NODE_DOT3:  return NEW_DOT3(from, to);
+			case NODE_FLIP2: return rb_node_newnode(NODE_FLIP2, from, to, 0);
+			case NODE_FLIP3: return rb_node_newnode(NODE_FLIP3, from, to, 0);
+			}
 		}
 		case NODE_FBODY:
 		{
