@@ -1,4 +1,4 @@
-// $Id: BRbWriteNode.cpp,v 1.51 2003/02/10 08:15:59 yuya Exp $
+// $Id: BRbWriteNode.cpp,v 1.53 2003/02/21 02:19:10 yuya Exp $
 
 #ifdef BRB_WRITER
 
@@ -23,16 +23,19 @@ BRbWriteNode::~BRbWriteNode()
 void
 BRbWriteNode::write(NODE* node, BRbOutputBuffer& buffer)
 {
-	m_debug.printf("writing header.\n");
 	write_header();
-	m_debug.printf("wrote header.\n");
 
+#ifdef DEBUG
 	m_debug.printf("============================================================\n");
 	m_debug.dumpnode(node);
 	m_debug.printf("============================================================\n");
-	m_debug.printf("writing node.\n");
+#endif
+
 	write_node_opt(node);
-	m_debug.printf("wrote node.\n");
+
+#ifdef DEBUG
+	m_debug.printf("============================================================\n");
+#endif
 
 	m_strtbl.dump(m_stbuf);
 
@@ -64,14 +67,16 @@ BRbWriteNode::write_node(NODE* node)
 		return;
 	}
 
- 	byte type = (byte)nd_type(node);
-	BRbLevelCounter counter(type);
+	byte type = (byte)nd_type(node);
 
+#ifdef DEBUG
+	BRbLevelCounter counter(type);
 	if ( type == NODE_NEWLINE ) {
 		m_debug.printf("W:%02i:%s [%s:%i]\n", counter.level(), BRbNode::get_node_name(type), node->nd_file, node->nd_nth);
 	} else {
 		m_debug.printf("W:%02i:%s\n", counter.level(), BRbNode::get_node_name(type));
 	}
+#endif
 
 	write_byte(type);
 
