@@ -1,4 +1,4 @@
-// $Id: exerb.cpp,v 1.97 2003/01/30 09:46:29 yuya Exp $
+// $Id: exerb.cpp,v 1.99 2003/02/20 09:18:47 yuya Exp $
 
 ////////////////////////////////////////////////////////////////////////////////
 
@@ -23,7 +23,6 @@ static void  ExCleanup();
 static void  ExFinalRuby();
 static int   ExFailed();
 static void  ExOnErrorID(int resource_id);
-static void  ExRaiseLoadError(int resource_id);
 static void  ExCreateTemporaryFile(char *filepath_buffer);
 static void  ExWriteFile(char *filepath, void *buffer, DWORD size);
 static void* ExReadFile(char *filepath);
@@ -124,7 +123,7 @@ ExMapping()
 {
 	PEXERB_DOS_HEADER dos_header = (PEXERB_DOS_HEADER)::GetModuleHandle(NULL);
 	if ( !dos_header->offset_to_archive || !dos_header->size_of_archive ) {
-	    ::ExOnErrorID(IDS_HEADER_NOT_FOUND);
+	    ::ExOnErrorID(IDS_FAIL_FIND_HEADER);
 	    return false;
 	}
 
@@ -134,17 +133,14 @@ ExMapping()
 	char filepath[MAX_PATH] = "";
 	::ExGetSelfFilePath(filepath, sizeof(filepath));
 
-	HANDLE file = ::CreateFile(filepath, GENERIC_READ, FILE_SHARE_READ, NULL, OPEN_EXISTING, FILE_ATTRIBUTE_NORMAL, NULL);
-	if ( file == INVALID_HANDLE_VALUE ) {
-		::ExOnErrorID(IDS_FAIL_CREATEFILE);
+	FILE *file = ::fopen(filepath, "rb");
+	if ( !file ) {
+		::ExOnErrorID(IDS_FAIL_READ_ARCHIVE);
 		return false;
 	}
-
-	DWORD read = 0;
-	::SetFilePointer(file, dos_header->offset_to_archive, 0, FILE_BEGIN);
-	::ReadFile(file, g_archive, archive_size, &read, NULL);
-
-	::CloseHandle(file);
+	::fseek(file, dos_header->offset_to_archive, SEEK_SET);
+	::fread(g_archive, archive_size, 1, file);
+	::fclose(file);
 
 	if ( dos_header->size_of_compressed_archive > 0 ) {
 #ifdef USE_ZLIB
@@ -175,7 +171,7 @@ ExSetup()
 	PEXERB_ARCHIVE_HEADER archive = (PEXERB_ARCHIVE_HEADER)g_archive;
 
 	if ( archive->number_of_entry == 0 ) {
-		::ExOnErrorID(IDS_SCRIPT_NOT_FOUND);
+		::ExOnErrorID(IDS_FAIL_FIND_SCRIPT);
 		return false;
 	}
 
@@ -215,7 +211,7 @@ ExSetupTable(PEXERB_ARCHIVE_HEADER archive)
 	}
 
 	if ( !g_startup_script_id ) {
-		::ExOnErrorID(IDS_SCRIPT_NOT_FOUND);
+		::ExOnErrorID(IDS_FAIL_FIND_SCRIPT);
 		return false;
 	}
 
@@ -322,12 +318,27 @@ ExOnErrorID(int resource_id)
 	::ExOnError(message);
 }
 
-static void
-ExRaiseLoadError(int resource_id)
+void
+ExRaiseException(VALUE klass, int res_id)
 {
 	char message[1024] = "";
-	::LoadString(::GetModuleHandle(NULL), resource_id, message, sizeof(message));
-	::rb_raise(rb_eLoadError, message);
+	::LoadString(::GetModuleHandle(NULL), res_id, message, sizeof(message));
+	::rb_raise(klass, message);
+}
+
+void
+ExRaiseExceptionVar(VALUE klass, int res_id, ...)
+{
+	char format[1024] = "";
+	::LoadString(::GetModuleHandle(NULL), res_id, format, sizeof(format));
+
+	char message[1024] = "";
+	va_list args;
+	va_start(args, res_id);
+	::vsnprintf(message, sizeof(message), format, args);
+	va_end(args);
+
+	::rb_raise(klass, message);
 }
 
 static void
@@ -415,7 +426,7 @@ ExLoadDll0(char *filepath, VALUE filename)
 
 	if ( !module ) {
 		::DeleteFile(filepath);
-		::rb_raise(rb_eLoadError, "LoadLibraryEx() failed. [Error:%i].", error);
+		::ExRaiseExceptionVar(rb_eLoadError, IDS_FAIL_CALL_LOADLIBRARYEX, error);
 		return NULL;
 	}
 
@@ -426,7 +437,7 @@ ExLoadDll0(char *filepath, VALUE filename)
 	if ( !init_proc ) {
 		::FreeLibrary(module);
 		::DeleteFile(filepath);
-		::ExRaiseLoadError(IDS_FAIL_GETPROCADDRESS);
+		::ExRaiseException(rb_eLoadError, IDS_FAIL_GET_PROCADDRESS);
 		return NULL;
 	}
 
@@ -587,7 +598,7 @@ ExLoadInsideLibrary(VALUE fname, DWORD id)
 	if ( !offset || !size ) return false;
 
 	if ( !::ExReplaceImportTable((void*)offset) ) {
-		::ExRaiseLoadError(IDS_FAIL_MODIFY_IMPORT_TABLE);
+		::ExRaiseException(rb_eLoadError, IDS_FAIL_MODIFY_IMPORT_TABLE);
 	}
 
 	char tmpfile[MAX_PATH] = "";
@@ -624,7 +635,7 @@ ExRequireOutside(VALUE fname)
 
 	VALUE realname, filename;
 	if ( !::ExFindOutsideFile(fname, &realname, &filename) ) {
-		::rb_raise(rb_eLoadError, "No such file to load -- %s", RSTRING(fname)->ptr);
+		::ExRaiseExceptionVar(rb_eLoadError, IDS_FAIL_FIND_FILE, RSTRING(fname)->ptr);
 	}
 
 	DEBUGMSG1("  fname    => %s\n", RSTRING(::rb_inspect(fname))->ptr);
@@ -647,7 +658,7 @@ ExRequireOutside(VALUE fname)
 		} else if ( ::stricmp(ext, ".so") == 0 || ::stricmp(ext, ".dll") == 0 ) {
 			::ExLoadOutsideLibrary(realname, filename);
 		} else {
-			::rb_raise(rb_eLoadError, "Unknown file type -- %s", RSTRING(fname)->ptr);
+			::ExRaiseExceptionVar(rb_eLoadError, IDS_FAIL_CHECK_TYPE, RSTRING(fname)->ptr);
 		}
 	} else {
 		::rb_bug("has not extension");
@@ -707,7 +718,7 @@ ExLoadOutsideLibrary(VALUE fname, VALUE name)
 	void  *buffer = ::ExReadFile(RSTRING(fname)->ptr, &size);
 
 	if ( !::ExReplaceImportTable(buffer) ) {
-		::ExRaiseLoadError(IDS_FAIL_MODIFY_IMPORT_TABLE);
+		::ExRaiseException(rb_eLoadError, IDS_FAIL_MODIFY_IMPORT_TABLE);
 	}
 
 	char tmpfile[MAX_PATH] = "";
